Module: ZoomInfo

Defined in:
lib/zoominfo-ruby/key_generation.rb,
lib/zoominfo-ruby/client.rb,
lib/zoominfo-ruby/person.rb,
lib/zoominfo-ruby/company.rb

Overview

As noted in the people_search_query input parameters table, the key is made up of a string consisting of 5 parameters concatenated together, and then encrypted with MD5. Parameters are:

The first 2 characters of each search term with a “yes” in the “Key” column, in the order listed in the input parameters table for the given query (below). If the value for a search term has only 1 character, then the key generation should use that single character. Your partner password Today’s day of the month (not padded with zero) Today’s month (not padded with zero) Today’s year (4 digit)

Defined Under Namespace

Modules: KeyGeneration Classes: Base, Company, Person